# coding: utf-8

"""
    Midgard Public API

    The Midgard Public API queries THORChain and any chains linked via the Bifröst and prepares information about the network to be readily available for public users. The API parses transaction event data from THORChain and stores them in a time-series database to make time-dependent queries easy. Midgard does not hold critical information. To interact with THORChain protocol, users should query THORNode directly.  # noqa: E501

    OpenAPI spec version: 2.20.1
    Contact: devs@thorchain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class MemberPool(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'asset_added': 'str',
        'asset_address': 'str',
        'asset_deposit': 'str',
        'asset_pending': 'str',
        'asset_withdrawn': 'str',
        'date_first_added': 'str',
        'date_last_added': 'str',
        'liquidity_units': 'str',
        'pool': 'str',
        'rune_added': 'str',
        'rune_address': 'str',
        'rune_deposit': 'str',
        'rune_pending': 'str',
        'rune_withdrawn': 'str'
    }

    attribute_map = {
        'asset_added': 'assetAdded',
        'asset_address': 'assetAddress',
        'asset_deposit': 'assetDeposit',
        'asset_pending': 'assetPending',
        'asset_withdrawn': 'assetWithdrawn',
        'date_first_added': 'dateFirstAdded',
        'date_last_added': 'dateLastAdded',
        'liquidity_units': 'liquidityUnits',
        'pool': 'pool',
        'rune_added': 'runeAdded',
        'rune_address': 'runeAddress',
        'rune_deposit': 'runeDeposit',
        'rune_pending': 'runePending',
        'rune_withdrawn': 'runeWithdrawn'
    }

    def __init__(self, asset_added=None, asset_address=None, asset_deposit=None, asset_pending=None, asset_withdrawn=None, date_first_added=None, date_last_added=None, liquidity_units=None, pool=None, rune_added=None, rune_address=None, rune_deposit=None, rune_pending=None, rune_withdrawn=None):  # noqa: E501
        """MemberPool - a model defined in Swagger"""  # noqa: E501
        self._asset_added = None
        self._asset_address = None
        self._asset_deposit = None
        self._asset_pending = None
        self._asset_withdrawn = None
        self._date_first_added = None
        self._date_last_added = None
        self._liquidity_units = None
        self._pool = None
        self._rune_added = None
        self._rune_address = None
        self._rune_deposit = None
        self._rune_pending = None
        self._rune_withdrawn = None
        self.discriminator = None
        self.asset_added = asset_added
        self.asset_address = asset_address
        self.asset_deposit = asset_deposit
        self.asset_pending = asset_pending
        self.asset_withdrawn = asset_withdrawn
        self.date_first_added = date_first_added
        self.date_last_added = date_last_added
        self.liquidity_units = liquidity_units
        self.pool = pool
        self.rune_added = rune_added
        self.rune_address = rune_address
        self.rune_deposit = rune_deposit
        self.rune_pending = rune_pending
        self.rune_withdrawn = rune_withdrawn

    @property
    def asset_added(self):
        """Gets the asset_added of this MemberPool.  # noqa: E501

        Int64(e8), total asset added to the pool by member  # noqa: E501

        :return: The asset_added of this MemberPool.  # noqa: E501
        :rtype: str
        """
        return self._asset_added

    @asset_added.setter
    def asset_added(self, asset_added):
        """Sets the asset_added of this MemberPool.

        Int64(e8), total asset added to the pool by member  # noqa: E501

        :param asset_added: The asset_added of this MemberPool.  # noqa: E501
        :type: str
        """
        if asset_added is None:
            raise ValueError("Invalid value for `asset_added`, must not be `None`")  # noqa: E501

        self._asset_added = asset_added

    @property
    def asset_address(self):
        """Gets the asset_address of this MemberPool.  # noqa: E501

        asset address used by the member  # noqa: E501

        :return: The asset_address of this MemberPool.  # noqa: E501
        :rtype: str
        """
        return self._asset_address

    @asset_address.setter
    def asset_address(self, asset_address):
        """Sets the asset_address of this MemberPool.

        asset address used by the member  # noqa: E501

        :param asset_address: The asset_address of this MemberPool.  # noqa: E501
        :type: str
        """
        if asset_address is None:
            raise ValueError("Invalid value for `asset_address`, must not be `None`")  # noqa: E501

        self._asset_address = asset_address

    @property
    def asset_deposit(self):
        """Gets the asset_deposit of this MemberPool.  # noqa: E501

        Int64(e8), total asset that is currently deposited to the pool by member. This field is same as the `asset_deposit_value` field in thornode. Mainly can be used  for tracking, mainly Growth Percentage   # noqa: E501

        :return: The asset_deposit of this MemberPool.  # noqa: E501
        :rtype: str
        """
        return self._asset_deposit

    @asset_deposit.setter
    def asset_deposit(self, asset_deposit):
        """Sets the asset_deposit of this MemberPool.

        Int64(e8), total asset that is currently deposited to the pool by member. This field is same as the `asset_deposit_value` field in thornode. Mainly can be used  for tracking, mainly Growth Percentage   # noqa: E501

        :param asset_deposit: The asset_deposit of this MemberPool.  # noqa: E501
        :type: str
        """
        if asset_deposit is None:
            raise ValueError("Invalid value for `asset_deposit`, must not be `None`")  # noqa: E501

        self._asset_deposit = asset_deposit

    @property
    def asset_pending(self):
        """Gets the asset_pending of this MemberPool.  # noqa: E501

        Int64(e8), asset sent but not added yet, it will be added when the rune pair arrives   # noqa: E501

        :return: The asset_pending of this MemberPool.  # noqa: E501
        :rtype: str
        """
        return self._asset_pending

    @asset_pending.setter
    def asset_pending(self, asset_pending):
        """Sets the asset_pending of this MemberPool.

        Int64(e8), asset sent but not added yet, it will be added when the rune pair arrives   # noqa: E501

        :param asset_pending: The asset_pending of this MemberPool.  # noqa: E501
        :type: str
        """
        if asset_pending is None:
            raise ValueError("Invalid value for `asset_pending`, must not be `None`")  # noqa: E501

        self._asset_pending = asset_pending

    @property
    def asset_withdrawn(self):
        """Gets the asset_withdrawn of this MemberPool.  # noqa: E501

        Int64(e8), total asset withdrawn from the pool by member  # noqa: E501

        :return: The asset_withdrawn of this MemberPool.  # noqa: E501
        :rtype: str
        """
        return self._asset_withdrawn

    @asset_withdrawn.setter
    def asset_withdrawn(self, asset_withdrawn):
        """Sets the asset_withdrawn of this MemberPool.

        Int64(e8), total asset withdrawn from the pool by member  # noqa: E501

        :param asset_withdrawn: The asset_withdrawn of this MemberPool.  # noqa: E501
        :type: str
        """
        if asset_withdrawn is None:
            raise ValueError("Invalid value for `asset_withdrawn`, must not be `None`")  # noqa: E501

        self._asset_withdrawn = asset_withdrawn

    @property
    def date_first_added(self):
        """Gets the date_first_added of this MemberPool.  # noqa: E501

        Int64, Unix timestamp for the first time member deposited into the pool  # noqa: E501

        :return: The date_first_added of this MemberPool.  # noqa: E501
        :rtype: str
        """
        return self._date_first_added

    @date_first_added.setter
    def date_first_added(self, date_first_added):
        """Sets the date_first_added of this MemberPool.

        Int64, Unix timestamp for the first time member deposited into the pool  # noqa: E501

        :param date_first_added: The date_first_added of this MemberPool.  # noqa: E501
        :type: str
        """
        if date_first_added is None:
            raise ValueError("Invalid value for `date_first_added`, must not be `None`")  # noqa: E501

        self._date_first_added = date_first_added

    @property
    def date_last_added(self):
        """Gets the date_last_added of this MemberPool.  # noqa: E501

        Int64, Unix timestamp for the last time member deposited into the pool  # noqa: E501

        :return: The date_last_added of this MemberPool.  # noqa: E501
        :rtype: str
        """
        return self._date_last_added

    @date_last_added.setter
    def date_last_added(self, date_last_added):
        """Sets the date_last_added of this MemberPool.

        Int64, Unix timestamp for the last time member deposited into the pool  # noqa: E501

        :param date_last_added: The date_last_added of this MemberPool.  # noqa: E501
        :type: str
        """
        if date_last_added is None:
            raise ValueError("Invalid value for `date_last_added`, must not be `None`")  # noqa: E501

        self._date_last_added = date_last_added

    @property
    def liquidity_units(self):
        """Gets the liquidity_units of this MemberPool.  # noqa: E501

        Int64, pool liquidity units that belong the the member  # noqa: E501

        :return: The liquidity_units of this MemberPool.  # noqa: E501
        :rtype: str
        """
        return self._liquidity_units

    @liquidity_units.setter
    def liquidity_units(self, liquidity_units):
        """Sets the liquidity_units of this MemberPool.

        Int64, pool liquidity units that belong the the member  # noqa: E501

        :param liquidity_units: The liquidity_units of this MemberPool.  # noqa: E501
        :type: str
        """
        if liquidity_units is None:
            raise ValueError("Invalid value for `liquidity_units`, must not be `None`")  # noqa: E501

        self._liquidity_units = liquidity_units

    @property
    def pool(self):
        """Gets the pool of this MemberPool.  # noqa: E501

        Pool rest of the data refers to  # noqa: E501

        :return: The pool of this MemberPool.  # noqa: E501
        :rtype: str
        """
        return self._pool

    @pool.setter
    def pool(self, pool):
        """Sets the pool of this MemberPool.

        Pool rest of the data refers to  # noqa: E501

        :param pool: The pool of this MemberPool.  # noqa: E501
        :type: str
        """
        if pool is None:
            raise ValueError("Invalid value for `pool`, must not be `None`")  # noqa: E501

        self._pool = pool

    @property
    def rune_added(self):
        """Gets the rune_added of this MemberPool.  # noqa: E501

        Int64(e8), total Rune added to the pool by member  # noqa: E501

        :return: The rune_added of this MemberPool.  # noqa: E501
        :rtype: str
        """
        return self._rune_added

    @rune_added.setter
    def rune_added(self, rune_added):
        """Sets the rune_added of this MemberPool.

        Int64(e8), total Rune added to the pool by member  # noqa: E501

        :param rune_added: The rune_added of this MemberPool.  # noqa: E501
        :type: str
        """
        if rune_added is None:
            raise ValueError("Invalid value for `rune_added`, must not be `None`")  # noqa: E501

        self._rune_added = rune_added

    @property
    def rune_address(self):
        """Gets the rune_address of this MemberPool.  # noqa: E501

        Rune address used by the member  # noqa: E501

        :return: The rune_address of this MemberPool.  # noqa: E501
        :rtype: str
        """
        return self._rune_address

    @rune_address.setter
    def rune_address(self, rune_address):
        """Sets the rune_address of this MemberPool.

        Rune address used by the member  # noqa: E501

        :param rune_address: The rune_address of this MemberPool.  # noqa: E501
        :type: str
        """
        if rune_address is None:
            raise ValueError("Invalid value for `rune_address`, must not be `None`")  # noqa: E501

        self._rune_address = rune_address

    @property
    def rune_deposit(self):
        """Gets the rune_deposit of this MemberPool.  # noqa: E501

        Int64(e8), total Rune that is currently deposited to the pool by member. This field is same as the `rune_deposit_value` field in thornode. Mainly can be used  for tracking, mainly Growth Percentage   # noqa: E501

        :return: The rune_deposit of this MemberPool.  # noqa: E501
        :rtype: str
        """
        return self._rune_deposit

    @rune_deposit.setter
    def rune_deposit(self, rune_deposit):
        """Sets the rune_deposit of this MemberPool.

        Int64(e8), total Rune that is currently deposited to the pool by member. This field is same as the `rune_deposit_value` field in thornode. Mainly can be used  for tracking, mainly Growth Percentage   # noqa: E501

        :param rune_deposit: The rune_deposit of this MemberPool.  # noqa: E501
        :type: str
        """
        if rune_deposit is None:
            raise ValueError("Invalid value for `rune_deposit`, must not be `None`")  # noqa: E501

        self._rune_deposit = rune_deposit

    @property
    def rune_pending(self):
        """Gets the rune_pending of this MemberPool.  # noqa: E501

        Int64(e8), Rune sent but not added yet, it will be added when the asset pair arrives   # noqa: E501

        :return: The rune_pending of this MemberPool.  # noqa: E501
        :rtype: str
        """
        return self._rune_pending

    @rune_pending.setter
    def rune_pending(self, rune_pending):
        """Sets the rune_pending of this MemberPool.

        Int64(e8), Rune sent but not added yet, it will be added when the asset pair arrives   # noqa: E501

        :param rune_pending: The rune_pending of this MemberPool.  # noqa: E501
        :type: str
        """
        if rune_pending is None:
            raise ValueError("Invalid value for `rune_pending`, must not be `None`")  # noqa: E501

        self._rune_pending = rune_pending

    @property
    def rune_withdrawn(self):
        """Gets the rune_withdrawn of this MemberPool.  # noqa: E501

        Int64(e8), total Rune withdrawn from the pool by member  # noqa: E501

        :return: The rune_withdrawn of this MemberPool.  # noqa: E501
        :rtype: str
        """
        return self._rune_withdrawn

    @rune_withdrawn.setter
    def rune_withdrawn(self, rune_withdrawn):
        """Sets the rune_withdrawn of this MemberPool.

        Int64(e8), total Rune withdrawn from the pool by member  # noqa: E501

        :param rune_withdrawn: The rune_withdrawn of this MemberPool.  # noqa: E501
        :type: str
        """
        if rune_withdrawn is None:
            raise ValueError("Invalid value for `rune_withdrawn`, must not be `None`")  # noqa: E501

        self._rune_withdrawn = rune_withdrawn

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(MemberPool, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MemberPool):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Midgard Public API

    The Midgard Public API queries THORChain and any chains linked via the Bifröst and prepares information about the network to be readily available for public users. The API parses transaction event data from THORChain and stores them in a time-series database to make time-dependent queries easy. Midgard does not hold critical information. To interact with THORChain protocol, users should query THORNode directly.  # noqa: E501

    OpenAPI spec version: 2.20.1
    Contact: devs@thorchain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class BondMetrics(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'average_active_bond': 'str',
        'average_standby_bond': 'str',
        'bond_hard_cap': 'str',
        'maximum_active_bond': 'str',
        'maximum_standby_bond': 'str',
        'median_active_bond': 'str',
        'median_standby_bond': 'str',
        'minimum_active_bond': 'str',
        'minimum_standby_bond': 'str',
        'total_active_bond': 'str',
        'total_standby_bond': 'str'
    }

    attribute_map = {
        'average_active_bond': 'averageActiveBond',
        'average_standby_bond': 'averageStandbyBond',
        'bond_hard_cap': 'bondHardCap',
        'maximum_active_bond': 'maximumActiveBond',
        'maximum_standby_bond': 'maximumStandbyBond',
        'median_active_bond': 'medianActiveBond',
        'median_standby_bond': 'medianStandbyBond',
        'minimum_active_bond': 'minimumActiveBond',
        'minimum_standby_bond': 'minimumStandbyBond',
        'total_active_bond': 'totalActiveBond',
        'total_standby_bond': 'totalStandbyBond'
    }

    def __init__(self, average_active_bond=None, average_standby_bond=None, bond_hard_cap=None, maximum_active_bond=None, maximum_standby_bond=None, median_active_bond=None, median_standby_bond=None, minimum_active_bond=None, minimum_standby_bond=None, total_active_bond=None, total_standby_bond=None):  # noqa: E501
        """BondMetrics - a model defined in Swagger"""  # noqa: E501
        self._average_active_bond = None
        self._average_standby_bond = None
        self._bond_hard_cap = None
        self._maximum_active_bond = None
        self._maximum_standby_bond = None
        self._median_active_bond = None
        self._median_standby_bond = None
        self._minimum_active_bond = None
        self._minimum_standby_bond = None
        self._total_active_bond = None
        self._total_standby_bond = None
        self.discriminator = None
        self.average_active_bond = average_active_bond
        self.average_standby_bond = average_standby_bond
        self.bond_hard_cap = bond_hard_cap
        self.maximum_active_bond = maximum_active_bond
        self.maximum_standby_bond = maximum_standby_bond
        self.median_active_bond = median_active_bond
        self.median_standby_bond = median_standby_bond
        self.minimum_active_bond = minimum_active_bond
        self.minimum_standby_bond = minimum_standby_bond
        self.total_active_bond = total_active_bond
        self.total_standby_bond = total_standby_bond

    @property
    def average_active_bond(self):
        """Gets the average_active_bond of this BondMetrics.  # noqa: E501

        Int64(e8), Average bond of active nodes  # noqa: E501

        :return: The average_active_bond of this BondMetrics.  # noqa: E501
        :rtype: str
        """
        return self._average_active_bond

    @average_active_bond.setter
    def average_active_bond(self, average_active_bond):
        """Sets the average_active_bond of this BondMetrics.

        Int64(e8), Average bond of active nodes  # noqa: E501

        :param average_active_bond: The average_active_bond of this BondMetrics.  # noqa: E501
        :type: str
        """
        if average_active_bond is None:
            raise ValueError("Invalid value for `average_active_bond`, must not be `None`")  # noqa: E501

        self._average_active_bond = average_active_bond

    @property
    def average_standby_bond(self):
        """Gets the average_standby_bond of this BondMetrics.  # noqa: E501

        Int64(e8), Average bond of standby nodes  # noqa: E501

        :return: The average_standby_bond of this BondMetrics.  # noqa: E501
        :rtype: str
        """
        return self._average_standby_bond

    @average_standby_bond.setter
    def average_standby_bond(self, average_standby_bond):
        """Sets the average_standby_bond of this BondMetrics.

        Int64(e8), Average bond of standby nodes  # noqa: E501

        :param average_standby_bond: The average_standby_bond of this BondMetrics.  # noqa: E501
        :type: str
        """
        if average_standby_bond is None:
            raise ValueError("Invalid value for `average_standby_bond`, must not be `None`")  # noqa: E501

        self._average_standby_bond = average_standby_bond

    @property
    def bond_hard_cap(self):
        """Gets the bond_hard_cap of this BondMetrics.  # noqa: E501

        Int64(e8), Highest effective bond for nodes  # noqa: E501

        :return: The bond_hard_cap of this BondMetrics.  # noqa: E501
        :rtype: str
        """
        return self._bond_hard_cap

    @bond_hard_cap.setter
    def bond_hard_cap(self, bond_hard_cap):
        """Sets the bond_hard_cap of this BondMetrics.

        Int64(e8), Highest effective bond for nodes  # noqa: E501

        :param bond_hard_cap: The bond_hard_cap of this BondMetrics.  # noqa: E501
        :type: str
        """
        if bond_hard_cap is None:
            raise ValueError("Invalid value for `bond_hard_cap`, must not be `None`")  # noqa: E501

        self._bond_hard_cap = bond_hard_cap

    @property
    def maximum_active_bond(self):
        """Gets the maximum_active_bond of this BondMetrics.  # noqa: E501

        Int64(e8), Maxinum bond of active nodes  # noqa: E501

        :return: The maximum_active_bond of this BondMetrics.  # noqa: E501
        :rtype: str
        """
        return self._maximum_active_bond

    @maximum_active_bond.setter
    def maximum_active_bond(self, maximum_active_bond):
        """Sets the maximum_active_bond of this BondMetrics.

        Int64(e8), Maxinum bond of active nodes  # noqa: E501

        :param maximum_active_bond: The maximum_active_bond of this BondMetrics.  # noqa: E501
        :type: str
        """
        if maximum_active_bond is None:
            raise ValueError("Invalid value for `maximum_active_bond`, must not be `None`")  # noqa: E501

        self._maximum_active_bond = maximum_active_bond

    @property
    def maximum_standby_bond(self):
        """Gets the maximum_standby_bond of this BondMetrics.  # noqa: E501

        Int64(e8), Maximum bond of standby nodes  # noqa: E501

        :return: The maximum_standby_bond of this BondMetrics.  # noqa: E501
        :rtype: str
        """
        return self._maximum_standby_bond

    @maximum_standby_bond.setter
    def maximum_standby_bond(self, maximum_standby_bond):
        """Sets the maximum_standby_bond of this BondMetrics.

        Int64(e8), Maximum bond of standby nodes  # noqa: E501

        :param maximum_standby_bond: The maximum_standby_bond of this BondMetrics.  # noqa: E501
        :type: str
        """
        if maximum_standby_bond is None:
            raise ValueError("Invalid value for `maximum_standby_bond`, must not be `None`")  # noqa: E501

        self._maximum_standby_bond = maximum_standby_bond

    @property
    def median_active_bond(self):
        """Gets the median_active_bond of this BondMetrics.  # noqa: E501

        Int64(e8), Median bond of active nodes  # noqa: E501

        :return: The median_active_bond of this BondMetrics.  # noqa: E501
        :rtype: str
        """
        return self._median_active_bond

    @median_active_bond.setter
    def median_active_bond(self, median_active_bond):
        """Sets the median_active_bond of this BondMetrics.

        Int64(e8), Median bond of active nodes  # noqa: E501

        :param median_active_bond: The median_active_bond of this BondMetrics.  # noqa: E501
        :type: str
        """
        if median_active_bond is None:
            raise ValueError("Invalid value for `median_active_bond`, must not be `None`")  # noqa: E501

        self._median_active_bond = median_active_bond

    @property
    def median_standby_bond(self):
        """Gets the median_standby_bond of this BondMetrics.  # noqa: E501

        Int64(e8), Median bond of standby nodes  # noqa: E501

        :return: The median_standby_bond of this BondMetrics.  # noqa: E501
        :rtype: str
        """
        return self._median_standby_bond

    @median_standby_bond.setter
    def median_standby_bond(self, median_standby_bond):
        """Sets the median_standby_bond of this BondMetrics.

        Int64(e8), Median bond of standby nodes  # noqa: E501

        :param median_standby_bond: The median_standby_bond of this BondMetrics.  # noqa: E501
        :type: str
        """
        if median_standby_bond is None:
            raise ValueError("Invalid value for `median_standby_bond`, must not be `None`")  # noqa: E501

        self._median_standby_bond = median_standby_bond

    @property
    def minimum_active_bond(self):
        """Gets the minimum_active_bond of this BondMetrics.  # noqa: E501

        Int64(e8), Minumum bond of active nodes  # noqa: E501

        :return: The minimum_active_bond of this BondMetrics.  # noqa: E501
        :rtype: str
        """
        return self._minimum_active_bond

    @minimum_active_bond.setter
    def minimum_active_bond(self, minimum_active_bond):
        """Sets the minimum_active_bond of this BondMetrics.

        Int64(e8), Minumum bond of active nodes  # noqa: E501

        :param minimum_active_bond: The minimum_active_bond of this BondMetrics.  # noqa: E501
        :type: str
        """
        if minimum_active_bond is None:
            raise ValueError("Invalid value for `minimum_active_bond`, must not be `None`")  # noqa: E501

        self._minimum_active_bond = minimum_active_bond

    @property
    def minimum_standby_bond(self):
        """Gets the minimum_standby_bond of this BondMetrics.  # noqa: E501

        Int64(e8), Minumum bond of standby nodes  # noqa: E501

        :return: The minimum_standby_bond of this BondMetrics.  # noqa: E501
        :rtype: str
        """
        return self._minimum_standby_bond

    @minimum_standby_bond.setter
    def minimum_standby_bond(self, minimum_standby_bond):
        """Sets the minimum_standby_bond of this BondMetrics.

        Int64(e8), Minumum bond of standby nodes  # noqa: E501

        :param minimum_standby_bond: The minimum_standby_bond of this BondMetrics.  # noqa: E501
        :type: str
        """
        if minimum_standby_bond is None:
            raise ValueError("Invalid value for `minimum_standby_bond`, must not be `None`")  # noqa: E501

        self._minimum_standby_bond = minimum_standby_bond

    @property
    def total_active_bond(self):
        """Gets the total_active_bond of this BondMetrics.  # noqa: E501

        Int64(e8), Total bond of active nodes  # noqa: E501

        :return: The total_active_bond of this BondMetrics.  # noqa: E501
        :rtype: str
        """
        return self._total_active_bond

    @total_active_bond.setter
    def total_active_bond(self, total_active_bond):
        """Sets the total_active_bond of this BondMetrics.

        Int64(e8), Total bond of active nodes  # noqa: E501

        :param total_active_bond: The total_active_bond of this BondMetrics.  # noqa: E501
        :type: str
        """
        if total_active_bond is None:
            raise ValueError("Invalid value for `total_active_bond`, must not be `None`")  # noqa: E501

        self._total_active_bond = total_active_bond

    @property
    def total_standby_bond(self):
        """Gets the total_standby_bond of this BondMetrics.  # noqa: E501

        Int64(e8), Total bond of standby nodes  # noqa: E501

        :return: The total_standby_bond of this BondMetrics.  # noqa: E501
        :rtype: str
        """
        return self._total_standby_bond

    @total_standby_bond.setter
    def total_standby_bond(self, total_standby_bond):
        """Sets the total_standby_bond of this BondMetrics.

        Int64(e8), Total bond of standby nodes  # noqa: E501

        :param total_standby_bond: The total_standby_bond of this BondMetrics.  # noqa: E501
        :type: str
        """
        if total_standby_bond is None:
            raise ValueError("Invalid value for `total_standby_bond`, must not be `None`")  # noqa: E501

        self._total_standby_bond = total_standby_bond

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(BondMetrics, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BondMetrics):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Midgard Public API

    The Midgard Public API queries THORChain and any chains linked via the Bifröst and prepares information about the network to be readily available for public users. The API parses transaction event data from THORChain and stores them in a time-series database to make time-dependent queries easy. Midgard does not hold critical information. To interact with THORChain protocol, users should query THORNode directly.  # noqa: E501

    OpenAPI spec version: 2.20.1
    Contact: devs@thorchain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class SaversHistoryMeta(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'end_savers_count': 'str',
        'end_savers_depth': 'str',
        'end_time': 'str',
        'end_units': 'str',
        'start_savers_count': 'str',
        'start_savers_depth': 'str',
        'start_time': 'str',
        'start_units': 'str'
    }

    attribute_map = {
        'end_savers_count': 'endSaversCount',
        'end_savers_depth': 'endSaversDepth',
        'end_time': 'endTime',
        'end_units': 'endUnits',
        'start_savers_count': 'startSaversCount',
        'start_savers_depth': 'startSaversDepth',
        'start_time': 'startTime',
        'start_units': 'startUnits'
    }

    def __init__(self, end_savers_count=None, end_savers_depth=None, end_time=None, end_units=None, start_savers_count=None, start_savers_depth=None, start_time=None, start_units=None):  # noqa: E501
        """SaversHistoryMeta - a model defined in Swagger"""  # noqa: E501
        self._end_savers_count = None
        self._end_savers_depth = None
        self._end_time = None
        self._end_units = None
        self._start_savers_count = None
        self._start_savers_depth = None
        self._start_time = None
        self._start_units = None
        self.discriminator = None
        self.end_savers_count = end_savers_count
        self.end_savers_depth = end_savers_depth
        self.end_time = end_time
        self.end_units = end_units
        self.start_savers_count = start_savers_count
        self.start_savers_depth = start_savers_depth
        self.start_time = start_time
        self.start_units = start_units

    @property
    def end_savers_count(self):
        """Gets the end_savers_count of this SaversHistoryMeta.  # noqa: E501

        Int64, Number of savers member in the savers vault at the end of the interval at time endTime  # noqa: E501

        :return: The end_savers_count of this SaversHistoryMeta.  # noqa: E501
        :rtype: str
        """
        return self._end_savers_count

    @end_savers_count.setter
    def end_savers_count(self, end_savers_count):
        """Sets the end_savers_count of this SaversHistoryMeta.

        Int64, Number of savers member in the savers vault at the end of the interval at time endTime  # noqa: E501

        :param end_savers_count: The end_savers_count of this SaversHistoryMeta.  # noqa: E501
        :type: str
        """
        if end_savers_count is None:
            raise ValueError("Invalid value for `end_savers_count`, must not be `None`")  # noqa: E501

        self._end_savers_count = end_savers_count

    @property
    def end_savers_depth(self):
        """Gets the end_savers_depth of this SaversHistoryMeta.  # noqa: E501

        Int64(e8), The depth in the savers vault at the end of the interval at time endTime   # noqa: E501

        :return: The end_savers_depth of this SaversHistoryMeta.  # noqa: E501
        :rtype: str
        """
        return self._end_savers_depth

    @end_savers_depth.setter
    def end_savers_depth(self, end_savers_depth):
        """Sets the end_savers_depth of this SaversHistoryMeta.

        Int64(e8), The depth in the savers vault at the end of the interval at time endTime   # noqa: E501

        :param end_savers_depth: The end_savers_depth of this SaversHistoryMeta.  # noqa: E501
        :type: str
        """
        if end_savers_depth is None:
            raise ValueError("Invalid value for `end_savers_depth`, must not be `None`")  # noqa: E501

        self._end_savers_depth = end_savers_depth

    @property
    def end_time(self):
        """Gets the end_time of this SaversHistoryMeta.  # noqa: E501

        Int64, The end time of bucket in unix timestamp  # noqa: E501

        :return: The end_time of this SaversHistoryMeta.  # noqa: E501
        :rtype: str
        """
        return self._end_time

    @end_time.setter
    def end_time(self, end_time):
        """Sets the end_time of this SaversHistoryMeta.

        Int64, The end time of bucket in unix timestamp  # noqa: E501

        :param end_time: The end_time of this SaversHistoryMeta.  # noqa: E501
        :type: str
        """
        if end_time is None:
            raise ValueError("Invalid value for `end_time`, must not be `None`")  # noqa: E501

        self._end_time = end_time

    @property
    def end_units(self):
        """Gets the end_units of this SaversHistoryMeta.  # noqa: E501

        Int64, Savers Units in the savers vault at the end of the interval at time endTime  # noqa: E501

        :return: The end_units of this SaversHistoryMeta.  # noqa: E501
        :rtype: str
        """
        return self._end_units

    @end_units.setter
    def end_units(self, end_units):
        """Sets the end_units of this SaversHistoryMeta.

        Int64, Savers Units in the savers vault at the end of the interval at time endTime  # noqa: E501

        :param end_units: The end_units of this SaversHistoryMeta.  # noqa: E501
        :type: str
        """
        if end_units is None:
            raise ValueError("Invalid value for `end_units`, must not be `None`")  # noqa: E501

        self._end_units = end_units

    @property
    def start_savers_count(self):
        """Gets the start_savers_count of this SaversHistoryMeta.  # noqa: E501

        Int64, Number of savers member in the savers vault at the start of the interval at time startTime   # noqa: E501

        :return: The start_savers_count of this SaversHistoryMeta.  # noqa: E501
        :rtype: str
        """
        return self._start_savers_count

    @start_savers_count.setter
    def start_savers_count(self, start_savers_count):
        """Sets the start_savers_count of this SaversHistoryMeta.

        Int64, Number of savers member in the savers vault at the start of the interval at time startTime   # noqa: E501

        :param start_savers_count: The start_savers_count of this SaversHistoryMeta.  # noqa: E501
        :type: str
        """
        if start_savers_count is None:
            raise ValueError("Invalid value for `start_savers_count`, must not be `None`")  # noqa: E501

        self._start_savers_count = start_savers_count

    @property
    def start_savers_depth(self):
        """Gets the start_savers_depth of this SaversHistoryMeta.  # noqa: E501

        Int64(e8), The depth in savers vault at the start of the interval at time startTime   # noqa: E501

        :return: The start_savers_depth of this SaversHistoryMeta.  # noqa: E501
        :rtype: str
        """
        return self._start_savers_depth

    @start_savers_depth.setter
    def start_savers_depth(self, start_savers_depth):
        """Sets the start_savers_depth of this SaversHistoryMeta.

        Int64(e8), The depth in savers vault at the start of the interval at time startTime   # noqa: E501

        :param start_savers_depth: The start_savers_depth of this SaversHistoryMeta.  # noqa: E501
        :type: str
        """
        if start_savers_depth is None:
            raise ValueError("Invalid value for `start_savers_depth`, must not be `None`")  # noqa: E501

        self._start_savers_depth = start_savers_depth

    @property
    def start_time(self):
        """Gets the start_time of this SaversHistoryMeta.  # noqa: E501

        Int64, The beginning time of bucket in unix timestamp  # noqa: E501

        :return: The start_time of this SaversHistoryMeta.  # noqa: E501
        :rtype: str
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """Sets the start_time of this SaversHistoryMeta.

        Int64, The beginning time of bucket in unix timestamp  # noqa: E501

        :param start_time: The start_time of this SaversHistoryMeta.  # noqa: E501
        :type: str
        """
        if start_time is None:
            raise ValueError("Invalid value for `start_time`, must not be `None`")  # noqa: E501

        self._start_time = start_time

    @property
    def start_units(self):
        """Gets the start_units of this SaversHistoryMeta.  # noqa: E501

        Int64, Savers Units in the savers vault at the start of the interval at time startTime   # noqa: E501

        :return: The start_units of this SaversHistoryMeta.  # noqa: E501
        :rtype: str
        """
        return self._start_units

    @start_units.setter
    def start_units(self, start_units):
        """Sets the start_units of this SaversHistoryMeta.

        Int64, Savers Units in the savers vault at the start of the interval at time startTime   # noqa: E501

        :param start_units: The start_units of this SaversHistoryMeta.  # noqa: E501
        :type: str
        """
        if start_units is None:
            raise ValueError("Invalid value for `start_units`, must not be `None`")  # noqa: E501

        self._start_units = start_units

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SaversHistoryMeta, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SaversHistoryMeta):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Midgard Public API

    The Midgard Public API queries THORChain and any chains linked via the Bifröst and prepares information about the network to be readily available for public users. The API parses transaction event data from THORChain and stores them in a time-series database to make time-dependent queries easy. Midgard does not hold critical information. To interact with THORChain protocol, users should query THORNode directly.  # noqa: E501

    OpenAPI spec version: 2.20.1
    Contact: devs@thorchain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class Health(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'database': 'bool',
        'genesis_info': 'GenesisInf',
        'in_sync': 'bool',
        'last_aggregated': 'HeightTS',
        'last_committed': 'HeightTS',
        'last_fetched': 'HeightTS',
        'last_thor_node': 'HeightTS',
        'scanner_height': 'str'
    }

    attribute_map = {
        'database': 'database',
        'genesis_info': 'genesisInfo',
        'in_sync': 'inSync',
        'last_aggregated': 'lastAggregated',
        'last_committed': 'lastCommitted',
        'last_fetched': 'lastFetched',
        'last_thor_node': 'lastThorNode',
        'scanner_height': 'scannerHeight'
    }

    def __init__(self, database=None, genesis_info=None, in_sync=None, last_aggregated=None, last_committed=None, last_fetched=None, last_thor_node=None, scanner_height=None):  # noqa: E501
        """Health - a model defined in Swagger"""  # noqa: E501
        self._database = None
        self._genesis_info = None
        self._in_sync = None
        self._last_aggregated = None
        self._last_committed = None
        self._last_fetched = None
        self._last_thor_node = None
        self._scanner_height = None
        self.discriminator = None
        self.database = database
        if genesis_info is not None:
            self.genesis_info = genesis_info
        self.in_sync = in_sync
        self.last_aggregated = last_aggregated
        self.last_committed = last_committed
        self.last_fetched = last_fetched
        self.last_thor_node = last_thor_node
        self.scanner_height = scanner_height

    @property
    def database(self):
        """Gets the database of this Health.  # noqa: E501

        True means healthy, connected to database  # noqa: E501

        :return: The database of this Health.  # noqa: E501
        :rtype: bool
        """
        return self._database

    @database.setter
    def database(self, database):
        """Sets the database of this Health.

        True means healthy, connected to database  # noqa: E501

        :param database: The database of this Health.  # noqa: E501
        :type: bool
        """
        if database is None:
            raise ValueError("Invalid value for `database`, must not be `None`")  # noqa: E501

        self._database = database

    @property
    def genesis_info(self):
        """Gets the genesis_info of this Health.  # noqa: E501


        :return: The genesis_info of this Health.  # noqa: E501
        :rtype: GenesisInf
        """
        return self._genesis_info

    @genesis_info.setter
    def genesis_info(self, genesis_info):
        """Sets the genesis_info of this Health.


        :param genesis_info: The genesis_info of this Health.  # noqa: E501
        :type: GenesisInf
        """

        self._genesis_info = genesis_info

    @property
    def in_sync(self):
        """Gets the in_sync of this Health.  # noqa: E501

        True means healthy. False means Midgard is still catching up to the chain  # noqa: E501

        :return: The in_sync of this Health.  # noqa: E501
        :rtype: bool
        """
        return self._in_sync

    @in_sync.setter
    def in_sync(self, in_sync):
        """Sets the in_sync of this Health.

        True means healthy. False means Midgard is still catching up to the chain  # noqa: E501

        :param in_sync: The in_sync of this Health.  # noqa: E501
        :type: bool
        """
        if in_sync is None:
            raise ValueError("Invalid value for `in_sync`, must not be `None`")  # noqa: E501

        self._in_sync = in_sync

    @property
    def last_aggregated(self):
        """Gets the last_aggregated of this Health.  # noqa: E501


        :return: The last_aggregated of this Health.  # noqa: E501
        :rtype: HeightTS
        """
        return self._last_aggregated

    @last_aggregated.setter
    def last_aggregated(self, last_aggregated):
        """Sets the last_aggregated of this Health.


        :param last_aggregated: The last_aggregated of this Health.  # noqa: E501
        :type: HeightTS
        """
        if last_aggregated is None:
            raise ValueError("Invalid value for `last_aggregated`, must not be `None`")  # noqa: E501

        self._last_aggregated = last_aggregated

    @property
    def last_committed(self):
        """Gets the last_committed of this Health.  # noqa: E501


        :return: The last_committed of this Health.  # noqa: E501
        :rtype: HeightTS
        """
        return self._last_committed

    @last_committed.setter
    def last_committed(self, last_committed):
        """Sets the last_committed of this Health.


        :param last_committed: The last_committed of this Health.  # noqa: E501
        :type: HeightTS
        """
        if last_committed is None:
            raise ValueError("Invalid value for `last_committed`, must not be `None`")  # noqa: E501

        self._last_committed = last_committed

    @property
    def last_fetched(self):
        """Gets the last_fetched of this Health.  # noqa: E501


        :return: The last_fetched of this Health.  # noqa: E501
        :rtype: HeightTS
        """
        return self._last_fetched

    @last_fetched.setter
    def last_fetched(self, last_fetched):
        """Sets the last_fetched of this Health.


        :param last_fetched: The last_fetched of this Health.  # noqa: E501
        :type: HeightTS
        """
        if last_fetched is None:
            raise ValueError("Invalid value for `last_fetched`, must not be `None`")  # noqa: E501

        self._last_fetched = last_fetched

    @property
    def last_thor_node(self):
        """Gets the last_thor_node of this Health.  # noqa: E501


        :return: The last_thor_node of this Health.  # noqa: E501
        :rtype: HeightTS
        """
        return self._last_thor_node

    @last_thor_node.setter
    def last_thor_node(self, last_thor_node):
        """Sets the last_thor_node of this Health.


        :param last_thor_node: The last_thor_node of this Health.  # noqa: E501
        :type: HeightTS
        """
        if last_thor_node is None:
            raise ValueError("Invalid value for `last_thor_node`, must not be `None`")  # noqa: E501

        self._last_thor_node = last_thor_node

    @property
    def scanner_height(self):
        """Gets the scanner_height of this Health.  # noqa: E501

        Int64, the current block count  # noqa: E501

        :return: The scanner_height of this Health.  # noqa: E501
        :rtype: str
        """
        return self._scanner_height

    @scanner_height.setter
    def scanner_height(self, scanner_height):
        """Sets the scanner_height of this Health.

        Int64, the current block count  # noqa: E501

        :param scanner_height: The scanner_height of this Health.  # noqa: E501
        :type: str
        """
        if scanner_height is None:
            raise ValueError("Invalid value for `scanner_height`, must not be `None`")  # noqa: E501

        self._scanner_height = scanner_height

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Health, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Health):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Midgard Public API

    The Midgard Public API queries THORChain and any chains linked via the Bifröst and prepares information about the network to be readily available for public users. The API parses transaction event data from THORChain and stores them in a time-series database to make time-dependent queries easy. Midgard does not hold critical information. To interact with THORChain protocol, users should query THORNode directly.  # noqa: E501

    OpenAPI spec version: 2.20.1
    Contact: devs@thorchain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from setuptools import setup, find_packages  # noqa: H301

NAME = "xchainpy2-midgard"
VERSION = "2.20.1"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = ["urllib3 >= 1.15", "six >= 1.10", "certifi", "python-dateutil"]
REQUIRES.append("aiohttp")


def load_description():
    """
    In setup call you do:
    long_description=load_description(),
    long_description_content_type="text/markdown",
    :return: text
    """
    from pathlib import Path
    this_directory = Path(__file__).parent
    long_description = (this_directory / "README.md").read_text()
    return long_description


setup(
    name=NAME,
    version=VERSION,
    description="Midgard Public API",
    author_email="devs@thorchain.org",
    url="",
    keywords=["Swagger", "Midgard Public API"],
    install_requires=REQUIRES,
    packages=find_packages(),
    include_package_data=True,
    long_description=load_description(),
    long_description_content_type="text/markdown",
)



# coding: utf-8

"""
    Midgard Public API

    The Midgard Public API queries THORChain and any chains linked via the Bifröst and prepares information about the network to be readily available for public users. The API parses transaction event data from THORChain and stores them in a time-series database to make time-dependent queries easy. Midgard does not hold critical information. To interact with THORChain protocol, users should query THORNode directly.  # noqa: E501

    OpenAPI spec version: 2.20.1
    Contact: devs@thorchain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class DepthHistoryItemPool(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'pool': 'str',
        'total_depth': 'str'
    }

    attribute_map = {
        'pool': 'pool',
        'total_depth': 'totalDepth'
    }

    def __init__(self, pool=None, total_depth=None):  # noqa: E501
        """DepthHistoryItemPool - a model defined in Swagger"""  # noqa: E501
        self._pool = None
        self._total_depth = None
        self.discriminator = None
        self.pool = pool
        self.total_depth = total_depth

    @property
    def pool(self):
        """Gets the pool of this DepthHistoryItemPool.  # noqa: E501

        asset for the given pool  # noqa: E501

        :return: The pool of this DepthHistoryItemPool.  # noqa: E501
        :rtype: str
        """
        return self._pool

    @pool.setter
    def pool(self, pool):
        """Sets the pool of this DepthHistoryItemPool.

        asset for the given pool  # noqa: E501

        :param pool: The pool of this DepthHistoryItemPool.  # noqa: E501
        :type: str
        """
        if pool is None:
            raise ValueError("Invalid value for `pool`, must not be `None`")  # noqa: E501

        self._pool = pool

    @property
    def total_depth(self):
        """Gets the total_depth of this DepthHistoryItemPool.  # noqa: E501

        Int64(e8) in rune, the total value in the pool (both assets and rune) at the end of the interval. Note: this is twice of the pool's Rune depth. (as pools are symmetrically balance)   # noqa: E501

        :return: The total_depth of this DepthHistoryItemPool.  # noqa: E501
        :rtype: str
        """
        return self._total_depth

    @total_depth.setter
    def total_depth(self, total_depth):
        """Sets the total_depth of this DepthHistoryItemPool.

        Int64(e8) in rune, the total value in the pool (both assets and rune) at the end of the interval. Note: this is twice of the pool's Rune depth. (as pools are symmetrically balance)   # noqa: E501

        :param total_depth: The total_depth of this DepthHistoryItemPool.  # noqa: E501
        :type: str
        """
        if total_depth is None:
            raise ValueError("Invalid value for `total_depth`, must not be `None`")  # noqa: E501

        self._total_depth = total_depth

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DepthHistoryItemPool, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DepthHistoryItemPool):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Midgard Public API

    The Midgard Public API queries THORChain and any chains linked via the Bifröst and prepares information about the network to be readily available for public users. The API parses transaction event data from THORChain and stores them in a time-series database to make time-dependent queries easy. Midgard does not hold critical information. To interact with THORChain protocol, users should query THORNode directly.  # noqa: E501

    OpenAPI spec version: 2.20.1
    Contact: devs@thorchain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class LiquidityHistoryItem(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'add_asset_liquidity_volume': 'str',
        'add_liquidity_count': 'str',
        'add_liquidity_volume': 'str',
        'add_rune_liquidity_volume': 'str',
        'end_time': 'str',
        'net': 'str',
        'rune_price_usd': 'str',
        'start_time': 'str',
        'withdraw_asset_volume': 'str',
        'withdraw_count': 'str',
        'withdraw_rune_volume': 'str',
        'withdraw_volume': 'str'
    }

    attribute_map = {
        'add_asset_liquidity_volume': 'addAssetLiquidityVolume',
        'add_liquidity_count': 'addLiquidityCount',
        'add_liquidity_volume': 'addLiquidityVolume',
        'add_rune_liquidity_volume': 'addRuneLiquidityVolume',
        'end_time': 'endTime',
        'net': 'net',
        'rune_price_usd': 'runePriceUSD',
        'start_time': 'startTime',
        'withdraw_asset_volume': 'withdrawAssetVolume',
        'withdraw_count': 'withdrawCount',
        'withdraw_rune_volume': 'withdrawRuneVolume',
        'withdraw_volume': 'withdrawVolume'
    }

    def __init__(self, add_asset_liquidity_volume=None, add_liquidity_count=None, add_liquidity_volume=None, add_rune_liquidity_volume=None, end_time=None, net=None, rune_price_usd=None, start_time=None, withdraw_asset_volume=None, withdraw_count=None, withdraw_rune_volume=None, withdraw_volume=None):  # noqa: E501
        """LiquidityHistoryItem - a model defined in Swagger"""  # noqa: E501
        self._add_asset_liquidity_volume = None
        self._add_liquidity_count = None
        self._add_liquidity_volume = None
        self._add_rune_liquidity_volume = None
        self._end_time = None
        self._net = None
        self._rune_price_usd = None
        self._start_time = None
        self._withdraw_asset_volume = None
        self._withdraw_count = None
        self._withdraw_rune_volume = None
        self._withdraw_volume = None
        self.discriminator = None
        self.add_asset_liquidity_volume = add_asset_liquidity_volume
        self.add_liquidity_count = add_liquidity_count
        self.add_liquidity_volume = add_liquidity_volume
        self.add_rune_liquidity_volume = add_rune_liquidity_volume
        self.end_time = end_time
        self.net = net
        self.rune_price_usd = rune_price_usd
        self.start_time = start_time
        self.withdraw_asset_volume = withdraw_asset_volume
        self.withdraw_count = withdraw_count
        self.withdraw_rune_volume = withdraw_rune_volume
        self.withdraw_volume = withdraw_volume

    @property
    def add_asset_liquidity_volume(self):
        """Gets the add_asset_liquidity_volume of this LiquidityHistoryItem.  # noqa: E501

        Int64(e8), total assets deposited during the time interval. Denoted in Rune using the price at deposit time.   # noqa: E501

        :return: The add_asset_liquidity_volume of this LiquidityHistoryItem.  # noqa: E501
        :rtype: str
        """
        return self._add_asset_liquidity_volume

    @add_asset_liquidity_volume.setter
    def add_asset_liquidity_volume(self, add_asset_liquidity_volume):
        """Sets the add_asset_liquidity_volume of this LiquidityHistoryItem.

        Int64(e8), total assets deposited during the time interval. Denoted in Rune using the price at deposit time.   # noqa: E501

        :param add_asset_liquidity_volume: The add_asset_liquidity_volume of this LiquidityHistoryItem.  # noqa: E501
        :type: str
        """
        if add_asset_liquidity_volume is None:
            raise ValueError("Invalid value for `add_asset_liquidity_volume`, must not be `None`")  # noqa: E501

        self._add_asset_liquidity_volume = add_asset_liquidity_volume

    @property
    def add_liquidity_count(self):
        """Gets the add_liquidity_count of this LiquidityHistoryItem.  # noqa: E501

        Int64, number of deposits during the time interval.   # noqa: E501

        :return: The add_liquidity_count of this LiquidityHistoryItem.  # noqa: E501
        :rtype: str
        """
        return self._add_liquidity_count

    @add_liquidity_count.setter
    def add_liquidity_count(self, add_liquidity_count):
        """Sets the add_liquidity_count of this LiquidityHistoryItem.

        Int64, number of deposits during the time interval.   # noqa: E501

        :param add_liquidity_count: The add_liquidity_count of this LiquidityHistoryItem.  # noqa: E501
        :type: str
        """
        if add_liquidity_count is None:
            raise ValueError("Invalid value for `add_liquidity_count`, must not be `None`")  # noqa: E501

        self._add_liquidity_count = add_liquidity_count

    @property
    def add_liquidity_volume(self):
        """Gets the add_liquidity_volume of this LiquidityHistoryItem.  # noqa: E501

        Int64(e8), total of rune and asset deposits. Denoted in Rune (using the price at deposit time).   # noqa: E501

        :return: The add_liquidity_volume of this LiquidityHistoryItem.  # noqa: E501
        :rtype: str
        """
        return self._add_liquidity_volume

    @add_liquidity_volume.setter
    def add_liquidity_volume(self, add_liquidity_volume):
        """Sets the add_liquidity_volume of this LiquidityHistoryItem.

        Int64(e8), total of rune and asset deposits. Denoted in Rune (using the price at deposit time).   # noqa: E501

        :param add_liquidity_volume: The add_liquidity_volume of this LiquidityHistoryItem.  # noqa: E501
        :type: str
        """
        if add_liquidity_volume is None:
            raise ValueError("Invalid value for `add_liquidity_volume`, must not be `None`")  # noqa: E501

        self._add_liquidity_volume = add_liquidity_volume

    @property
    def add_rune_liquidity_volume(self):
        """Gets the add_rune_liquidity_volume of this LiquidityHistoryItem.  # noqa: E501

        Int64(e8), total Rune deposited during the time interval.   # noqa: E501

        :return: The add_rune_liquidity_volume of this LiquidityHistoryItem.  # noqa: E501
        :rtype: str
        """
        return self._add_rune_liquidity_volume

    @add_rune_liquidity_volume.setter
    def add_rune_liquidity_volume(self, add_rune_liquidity_volume):
        """Sets the add_rune_liquidity_volume of this LiquidityHistoryItem.

        Int64(e8), total Rune deposited during the time interval.   # noqa: E501

        :param add_rune_liquidity_volume: The add_rune_liquidity_volume of this LiquidityHistoryItem.  # noqa: E501
        :type: str
        """
        if add_rune_liquidity_volume is None:
            raise ValueError("Invalid value for `add_rune_liquidity_volume`, must not be `None`")  # noqa: E501

        self._add_rune_liquidity_volume = add_rune_liquidity_volume

    @property
    def end_time(self):
        """Gets the end_time of this LiquidityHistoryItem.  # noqa: E501

        Int64, The end time of bucket in unix timestamp  # noqa: E501

        :return: The end_time of this LiquidityHistoryItem.  # noqa: E501
        :rtype: str
        """
        return self._end_time

    @end_time.setter
    def end_time(self, end_time):
        """Sets the end_time of this LiquidityHistoryItem.

        Int64, The end time of bucket in unix timestamp  # noqa: E501

        :param end_time: The end_time of this LiquidityHistoryItem.  # noqa: E501
        :type: str
        """
        if end_time is None:
            raise ValueError("Invalid value for `end_time`, must not be `None`")  # noqa: E501

        self._end_time = end_time

    @property
    def net(self):
        """Gets the net of this LiquidityHistoryItem.  # noqa: E501

        Int64(e8), net liquidity changes (withdrawals - deposits) during the time interval   # noqa: E501

        :return: The net of this LiquidityHistoryItem.  # noqa: E501
        :rtype: str
        """
        return self._net

    @net.setter
    def net(self, net):
        """Sets the net of this LiquidityHistoryItem.

        Int64(e8), net liquidity changes (withdrawals - deposits) during the time interval   # noqa: E501

        :param net: The net of this LiquidityHistoryItem.  # noqa: E501
        :type: str
        """
        if net is None:
            raise ValueError("Invalid value for `net`, must not be `None`")  # noqa: E501

        self._net = net

    @property
    def rune_price_usd(self):
        """Gets the rune_price_usd of this LiquidityHistoryItem.  # noqa: E501

        Float, the price of Rune based on the deepest USD pool at the end of the interval.   # noqa: E501

        :return: The rune_price_usd of this LiquidityHistoryItem.  # noqa: E501
        :rtype: str
        """
        return self._rune_price_usd

    @rune_price_usd.setter
    def rune_price_usd(self, rune_price_usd):
        """Sets the rune_price_usd of this LiquidityHistoryItem.

        Float, the price of Rune based on the deepest USD pool at the end of the interval.   # noqa: E501

        :param rune_price_usd: The rune_price_usd of this LiquidityHistoryItem.  # noqa: E501
        :type: str
        """
        if rune_price_usd is None:
            raise ValueError("Invalid value for `rune_price_usd`, must not be `None`")  # noqa: E501

        self._rune_price_usd = rune_price_usd

    @property
    def start_time(self):
        """Gets the start_time of this LiquidityHistoryItem.  # noqa: E501

        Int64, The beginning time of bucket in unix timestamp  # noqa: E501

        :return: The start_time of this LiquidityHistoryItem.  # noqa: E501
        :rtype: str
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """Sets the start_time of this LiquidityHistoryItem.

        Int64, The beginning time of bucket in unix timestamp  # noqa: E501

        :param start_time: The start_time of this LiquidityHistoryItem.  # noqa: E501
        :type: str
        """
        if start_time is None:
            raise ValueError("Invalid value for `start_time`, must not be `None`")  # noqa: E501

        self._start_time = start_time

    @property
    def withdraw_asset_volume(self):
        """Gets the withdraw_asset_volume of this LiquidityHistoryItem.  # noqa: E501

        Int64(e8), total assets withdrawn during the time interval. Denoted in Rune using the price at withdraw time.   # noqa: E501

        :return: The withdraw_asset_volume of this LiquidityHistoryItem.  # noqa: E501
        :rtype: str
        """
        return self._withdraw_asset_volume

    @withdraw_asset_volume.setter
    def withdraw_asset_volume(self, withdraw_asset_volume):
        """Sets the withdraw_asset_volume of this LiquidityHistoryItem.

        Int64(e8), total assets withdrawn during the time interval. Denoted in Rune using the price at withdraw time.   # noqa: E501

        :param withdraw_asset_volume: The withdraw_asset_volume of this LiquidityHistoryItem.  # noqa: E501
        :type: str
        """
        if withdraw_asset_volume is None:
            raise ValueError("Invalid value for `withdraw_asset_volume`, must not be `None`")  # noqa: E501

        self._withdraw_asset_volume = withdraw_asset_volume

    @property
    def withdraw_count(self):
        """Gets the withdraw_count of this LiquidityHistoryItem.  # noqa: E501

        Int64, number of withdraw during the time interval.   # noqa: E501

        :return: The withdraw_count of this LiquidityHistoryItem.  # noqa: E501
        :rtype: str
        """
        return self._withdraw_count

    @withdraw_count.setter
    def withdraw_count(self, withdraw_count):
        """Sets the withdraw_count of this LiquidityHistoryItem.

        Int64, number of withdraw during the time interval.   # noqa: E501

        :param withdraw_count: The withdraw_count of this LiquidityHistoryItem.  # noqa: E501
        :type: str
        """
        if withdraw_count is None:
            raise ValueError("Invalid value for `withdraw_count`, must not be `None`")  # noqa: E501

        self._withdraw_count = withdraw_count

    @property
    def withdraw_rune_volume(self):
        """Gets the withdraw_rune_volume of this LiquidityHistoryItem.  # noqa: E501

        Int64(e8), total Rune withdrawn during the time interval.   # noqa: E501

        :return: The withdraw_rune_volume of this LiquidityHistoryItem.  # noqa: E501
        :rtype: str
        """
        return self._withdraw_rune_volume

    @withdraw_rune_volume.setter
    def withdraw_rune_volume(self, withdraw_rune_volume):
        """Sets the withdraw_rune_volume of this LiquidityHistoryItem.

        Int64(e8), total Rune withdrawn during the time interval.   # noqa: E501

        :param withdraw_rune_volume: The withdraw_rune_volume of this LiquidityHistoryItem.  # noqa: E501
        :type: str
        """
        if withdraw_rune_volume is None:
            raise ValueError("Invalid value for `withdraw_rune_volume`, must not be `None`")  # noqa: E501

        self._withdraw_rune_volume = withdraw_rune_volume

    @property
    def withdraw_volume(self):
        """Gets the withdraw_volume of this LiquidityHistoryItem.  # noqa: E501

        Int64(e8), total of rune and asset withdrawals. Denoted in Rune (using the price at withdraw time).   # noqa: E501

        :return: The withdraw_volume of this LiquidityHistoryItem.  # noqa: E501
        :rtype: str
        """
        return self._withdraw_volume

    @withdraw_volume.setter
    def withdraw_volume(self, withdraw_volume):
        """Sets the withdraw_volume of this LiquidityHistoryItem.

        Int64(e8), total of rune and asset withdrawals. Denoted in Rune (using the price at withdraw time).   # noqa: E501

        :param withdraw_volume: The withdraw_volume of this LiquidityHistoryItem.  # noqa: E501
        :type: str
        """
        if withdraw_volume is None:
            raise ValueError("Invalid value for `withdraw_volume`, must not be `None`")  # noqa: E501

        self._withdraw_volume = withdraw_volume

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(LiquidityHistoryItem, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LiquidityHistoryItem):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Midgard Public API

    The Midgard Public API queries THORChain and any chains linked via the Bifröst and prepares information about the network to be readily available for public users. The API parses transaction event data from THORChain and stores them in a time-series database to make time-dependent queries easy. Midgard does not hold critical information. To interact with THORChain protocol, users should query THORNode directly.  # noqa: E501

    OpenAPI spec version: 2.20.1
    Contact: devs@thorchain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class Network(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'active_bonds': 'list[str]',
        'active_node_count': 'str',
        'block_rewards': 'BlockRewards',
        'bond_metrics': 'BondMetrics',
        'bonding_apy': 'str',
        'liquidity_apy': 'str',
        'next_churn_height': 'str',
        'pool_activation_countdown': 'str',
        'pool_share_factor': 'str',
        'standby_bonds': 'list[str]',
        'standby_node_count': 'str',
        'total_pooled_rune': 'str',
        'total_reserve': 'str'
    }

    attribute_map = {
        'active_bonds': 'activeBonds',
        'active_node_count': 'activeNodeCount',
        'block_rewards': 'blockRewards',
        'bond_metrics': 'bondMetrics',
        'bonding_apy': 'bondingAPY',
        'liquidity_apy': 'liquidityAPY',
        'next_churn_height': 'nextChurnHeight',
        'pool_activation_countdown': 'poolActivationCountdown',
        'pool_share_factor': 'poolShareFactor',
        'standby_bonds': 'standbyBonds',
        'standby_node_count': 'standbyNodeCount',
        'total_pooled_rune': 'totalPooledRune',
        'total_reserve': 'totalReserve'
    }

    def __init__(self, active_bonds=None, active_node_count=None, block_rewards=None, bond_metrics=None, bonding_apy=None, liquidity_apy=None, next_churn_height=None, pool_activation_countdown=None, pool_share_factor=None, standby_bonds=None, standby_node_count=None, total_pooled_rune=None, total_reserve=None):  # noqa: E501
        """Network - a model defined in Swagger"""  # noqa: E501
        self._active_bonds = None
        self._active_node_count = None
        self._block_rewards = None
        self._bond_metrics = None
        self._bonding_apy = None
        self._liquidity_apy = None
        self._next_churn_height = None
        self._pool_activation_countdown = None
        self._pool_share_factor = None
        self._standby_bonds = None
        self._standby_node_count = None
        self._total_pooled_rune = None
        self._total_reserve = None
        self.discriminator = None
        self.active_bonds = active_bonds
        self.active_node_count = active_node_count
        self.block_rewards = block_rewards
        self.bond_metrics = bond_metrics
        self.bonding_apy = bonding_apy
        self.liquidity_apy = liquidity_apy
        self.next_churn_height = next_churn_height
        self.pool_activation_countdown = pool_activation_countdown
        self.pool_share_factor = pool_share_factor
        self.standby_bonds = standby_bonds
        self.standby_node_count = standby_node_count
        self.total_pooled_rune = total_pooled_rune
        self.total_reserve = total_reserve

    @property
    def active_bonds(self):
        """Gets the active_bonds of this Network.  # noqa: E501

        Array of rune amounts (e8) bonded by each active node.   # noqa: E501

        :return: The active_bonds of this Network.  # noqa: E501
        :rtype: list[str]
        """
        return self._active_bonds

    @active_bonds.setter
    def active_bonds(self, active_bonds):
        """Sets the active_bonds of this Network.

        Array of rune amounts (e8) bonded by each active node.   # noqa: E501

        :param active_bonds: The active_bonds of this Network.  # noqa: E501
        :type: list[str]
        """
        if active_bonds is None:
            raise ValueError("Invalid value for `active_bonds`, must not be `None`")  # noqa: E501

        self._active_bonds = active_bonds

    @property
    def active_node_count(self):
        """Gets the active_node_count of this Network.  # noqa: E501

        Int64, Number of active nodes  # noqa: E501

        :return: The active_node_count of this Network.  # noqa: E501
        :rtype: str
        """
        return self._active_node_count

    @active_node_count.setter
    def active_node_count(self, active_node_count):
        """Sets the active_node_count of this Network.

        Int64, Number of active nodes  # noqa: E501

        :param active_node_count: The active_node_count of this Network.  # noqa: E501
        :type: str
        """
        if active_node_count is None:
            raise ValueError("Invalid value for `active_node_count`, must not be `None`")  # noqa: E501

        self._active_node_count = active_node_count

    @property
    def block_rewards(self):
        """Gets the block_rewards of this Network.  # noqa: E501


        :return: The block_rewards of this Network.  # noqa: E501
        :rtype: BlockRewards
        """
        return self._block_rewards

    @block_rewards.setter
    def block_rewards(self, block_rewards):
        """Sets the block_rewards of this Network.


        :param block_rewards: The block_rewards of this Network.  # noqa: E501
        :type: BlockRewards
        """
        if block_rewards is None:
            raise ValueError("Invalid value for `block_rewards`, must not be `None`")  # noqa: E501

        self._block_rewards = block_rewards

    @property
    def bond_metrics(self):
        """Gets the bond_metrics of this Network.  # noqa: E501


        :return: The bond_metrics of this Network.  # noqa: E501
        :rtype: BondMetrics
        """
        return self._bond_metrics

    @bond_metrics.setter
    def bond_metrics(self, bond_metrics):
        """Sets the bond_metrics of this Network.


        :param bond_metrics: The bond_metrics of this Network.  # noqa: E501
        :type: BondMetrics
        """
        if bond_metrics is None:
            raise ValueError("Invalid value for `bond_metrics`, must not be `None`")  # noqa: E501

        self._bond_metrics = bond_metrics

    @property
    def bonding_apy(self):
        """Gets the bonding_apy of this Network.  # noqa: E501

        Float, E.g. 0.01 = 1%. Estimate of the compounded bonding earnings based on the current reserve size, emmission curve, blocks per year and pool share factor = (WeeklyBondIncome/BondAmount + 1)^52 - 1   # noqa: E501

        :return: The bonding_apy of this Network.  # noqa: E501
        :rtype: str
        """
        return self._bonding_apy

    @bonding_apy.setter
    def bonding_apy(self, bonding_apy):
        """Sets the bonding_apy of this Network.

        Float, E.g. 0.01 = 1%. Estimate of the compounded bonding earnings based on the current reserve size, emmission curve, blocks per year and pool share factor = (WeeklyBondIncome/BondAmount + 1)^52 - 1   # noqa: E501

        :param bonding_apy: The bonding_apy of this Network.  # noqa: E501
        :type: str
        """
        if bonding_apy is None:
            raise ValueError("Invalid value for `bonding_apy`, must not be `None`")  # noqa: E501

        self._bonding_apy = bonding_apy

    @property
    def liquidity_apy(self):
        """Gets the liquidity_apy of this Network.  # noqa: E501

        Float, E.g. 0.01 = 1%. Estimate of the compounded  liquidity provider earnings based on the current reserve size, emmission curve, blocks per year and pool share factor = (WeeklyLiquidityIncome/(totalPooledRune*2) + 1)^52 - 1   # noqa: E501

        :return: The liquidity_apy of this Network.  # noqa: E501
        :rtype: str
        """
        return self._liquidity_apy

    @liquidity_apy.setter
    def liquidity_apy(self, liquidity_apy):
        """Sets the liquidity_apy of this Network.

        Float, E.g. 0.01 = 1%. Estimate of the compounded  liquidity provider earnings based on the current reserve size, emmission curve, blocks per year and pool share factor = (WeeklyLiquidityIncome/(totalPooledRune*2) + 1)^52 - 1   # noqa: E501

        :param liquidity_apy: The liquidity_apy of this Network.  # noqa: E501
        :type: str
        """
        if liquidity_apy is None:
            raise ValueError("Invalid value for `liquidity_apy`, must not be `None`")  # noqa: E501

        self._liquidity_apy = liquidity_apy

    @property
    def next_churn_height(self):
        """Gets the next_churn_height of this Network.  # noqa: E501

        Int64, height (block number) of the next churn.  # noqa: E501

        :return: The next_churn_height of this Network.  # noqa: E501
        :rtype: str
        """
        return self._next_churn_height

    @next_churn_height.setter
    def next_churn_height(self, next_churn_height):
        """Sets the next_churn_height of this Network.

        Int64, height (block number) of the next churn.  # noqa: E501

        :param next_churn_height: The next_churn_height of this Network.  # noqa: E501
        :type: str
        """
        if next_churn_height is None:
            raise ValueError("Invalid value for `next_churn_height`, must not be `None`")  # noqa: E501

        self._next_churn_height = next_churn_height

    @property
    def pool_activation_countdown(self):
        """Gets the pool_activation_countdown of this Network.  # noqa: E501

        Int64, the remaining time of pool activation (in blocks)  # noqa: E501

        :return: The pool_activation_countdown of this Network.  # noqa: E501
        :rtype: str
        """
        return self._pool_activation_countdown

    @pool_activation_countdown.setter
    def pool_activation_countdown(self, pool_activation_countdown):
        """Sets the pool_activation_countdown of this Network.

        Int64, the remaining time of pool activation (in blocks)  # noqa: E501

        :param pool_activation_countdown: The pool_activation_countdown of this Network.  # noqa: E501
        :type: str
        """
        if pool_activation_countdown is None:
            raise ValueError("Invalid value for `pool_activation_countdown`, must not be `None`")  # noqa: E501

        self._pool_activation_countdown = pool_activation_countdown

    @property
    def pool_share_factor(self):
        """Gets the pool_share_factor of this Network.  # noqa: E501

        Float [0..1], the ratio which is used to split earnings between liquidity provider and nodes. LPIncome = rewards * poolShareFactor ; BondIncome :=  rewards * (1 - poolShareFactor)   # noqa: E501

        :return: The pool_share_factor of this Network.  # noqa: E501
        :rtype: str
        """
        return self._pool_share_factor

    @pool_share_factor.setter
    def pool_share_factor(self, pool_share_factor):
        """Sets the pool_share_factor of this Network.

        Float [0..1], the ratio which is used to split earnings between liquidity provider and nodes. LPIncome = rewards * poolShareFactor ; BondIncome :=  rewards * (1 - poolShareFactor)   # noqa: E501

        :param pool_share_factor: The pool_share_factor of this Network.  # noqa: E501
        :type: str
        """
        if pool_share_factor is None:
            raise ValueError("Invalid value for `pool_share_factor`, must not be `None`")  # noqa: E501

        self._pool_share_factor = pool_share_factor

    @property
    def standby_bonds(self):
        """Gets the standby_bonds of this Network.  # noqa: E501

        Array of rune amounts (e8) bonded by each standby node.   # noqa: E501

        :return: The standby_bonds of this Network.  # noqa: E501
        :rtype: list[str]
        """
        return self._standby_bonds

    @standby_bonds.setter
    def standby_bonds(self, standby_bonds):
        """Sets the standby_bonds of this Network.

        Array of rune amounts (e8) bonded by each standby node.   # noqa: E501

        :param standby_bonds: The standby_bonds of this Network.  # noqa: E501
        :type: list[str]
        """
        if standby_bonds is None:
            raise ValueError("Invalid value for `standby_bonds`, must not be `None`")  # noqa: E501

        self._standby_bonds = standby_bonds

    @property
    def standby_node_count(self):
        """Gets the standby_node_count of this Network.  # noqa: E501

        Int64, Number of standby nodes, some of them might become active at the next churn.   # noqa: E501

        :return: The standby_node_count of this Network.  # noqa: E501
        :rtype: str
        """
        return self._standby_node_count

    @standby_node_count.setter
    def standby_node_count(self, standby_node_count):
        """Sets the standby_node_count of this Network.

        Int64, Number of standby nodes, some of them might become active at the next churn.   # noqa: E501

        :param standby_node_count: The standby_node_count of this Network.  # noqa: E501
        :type: str
        """
        if standby_node_count is None:
            raise ValueError("Invalid value for `standby_node_count`, must not be `None`")  # noqa: E501

        self._standby_node_count = standby_node_count

    @property
    def total_pooled_rune(self):
        """Gets the total_pooled_rune of this Network.  # noqa: E501

        Int64(e8), total Rune in all pools. Because asset and Rune value is the same amount in every pool (by definition), the total amount pooled is totalPooledRune*2.   # noqa: E501

        :return: The total_pooled_rune of this Network.  # noqa: E501
        :rtype: str
        """
        return self._total_pooled_rune

    @total_pooled_rune.setter
    def total_pooled_rune(self, total_pooled_rune):
        """Sets the total_pooled_rune of this Network.

        Int64(e8), total Rune in all pools. Because asset and Rune value is the same amount in every pool (by definition), the total amount pooled is totalPooledRune*2.   # noqa: E501

        :param total_pooled_rune: The total_pooled_rune of this Network.  # noqa: E501
        :type: str
        """
        if total_pooled_rune is None:
            raise ValueError("Invalid value for `total_pooled_rune`, must not be `None`")  # noqa: E501

        self._total_pooled_rune = total_pooled_rune

    @property
    def total_reserve(self):
        """Gets the total_reserve of this Network.  # noqa: E501

        Int64(e8), Current size of the Reserve.  # noqa: E501

        :return: The total_reserve of this Network.  # noqa: E501
        :rtype: str
        """
        return self._total_reserve

    @total_reserve.setter
    def total_reserve(self, total_reserve):
        """Sets the total_reserve of this Network.

        Int64(e8), Current size of the Reserve.  # noqa: E501

        :param total_reserve: The total_reserve of this Network.  # noqa: E501
        :type: str
        """
        if total_reserve is None:
            raise ValueError("Invalid value for `total_reserve`, must not be `None`")  # noqa: E501

        self._total_reserve = total_reserve

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Network, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Network):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# flake8: noqa
"""
    Midgard Public API

    The Midgard Public API queries THORChain and any chains linked via the Bifröst and prepares information about the network to be readily available for public users. The API parses transaction event data from THORChain and stores them in a time-series database to make time-dependent queries easy. Midgard does not hold critical information. To interact with THORChain protocol, users should query THORNode directly.  # noqa: E501

    OpenAPI spec version: 2.20.1
    Contact: devs@thorchain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

# import models into model package
from xchainpy2_midgard.models.action import Action
from xchainpy2_midgard.models.action_meta import ActionMeta
from xchainpy2_midgard.models.add_liquidity_metadata import AddLiquidityMetadata
from xchainpy2_midgard.models.balance import Balance
from xchainpy2_midgard.models.block_rewards import BlockRewards
from xchainpy2_midgard.models.bond_metrics import BondMetrics
from xchainpy2_midgard.models.borrower_details import BorrowerDetails
from xchainpy2_midgard.models.borrower_pool import BorrowerPool
from xchainpy2_midgard.models.borrowers import Borrowers
from xchainpy2_midgard.models.churn_item import ChurnItem
from xchainpy2_midgard.models.churns import Churns
from xchainpy2_midgard.models.coin import Coin
from xchainpy2_midgard.models.coins import Coins
from xchainpy2_midgard.models.depth_history import DepthHistory
from xchainpy2_midgard.models.depth_history_intervals import DepthHistoryIntervals
from xchainpy2_midgard.models.depth_history_item import DepthHistoryItem
from xchainpy2_midgard.models.depth_history_item_pool import DepthHistoryItemPool
from xchainpy2_midgard.models.depth_history_meta import DepthHistoryMeta
from xchainpy2_midgard.models.earnings_history import EarningsHistory
from xchainpy2_midgard.models.earnings_history_intervals import EarningsHistoryIntervals
from xchainpy2_midgard.models.earnings_history_item import EarningsHistoryItem
from xchainpy2_midgard.models.earnings_history_item_pool import EarningsHistoryItemPool
from xchainpy2_midgard.models.genesis_inf import GenesisInf
from xchainpy2_midgard.models.health import Health
from xchainpy2_midgard.models.height_ts import HeightTS
from xchainpy2_midgard.models.inline_response200 import InlineResponse200
from xchainpy2_midgard.models.known_pools import KnownPools
from xchainpy2_midgard.models.liquidity_history import LiquidityHistory
from xchainpy2_midgard.models.liquidity_history_intervals import LiquidityHistoryIntervals
from xchainpy2_midgard.models.liquidity_history_item import LiquidityHistoryItem
from xchainpy2_midgard.models.member_details import MemberDetails
from xchainpy2_midgard.models.member_pool import MemberPool
from xchainpy2_midgard.models.members import Members
from xchainpy2_midgard.models.metadata import Metadata
from xchainpy2_midgard.models.network import Network
from xchainpy2_midgard.models.network_fees import NetworkFees
from xchainpy2_midgard.models.node import Node
from xchainpy2_midgard.models.nodes import Nodes
from xchainpy2_midgard.models.pool_detail import PoolDetail
from xchainpy2_midgard.models.pool_details import PoolDetails
from xchainpy2_midgard.models.pool_stats_detail import PoolStatsDetail
from xchainpy2_midgard.models.refund_metadata import RefundMetadata
from xchainpy2_midgard.models.reverse_thor_names import ReverseTHORNames
from xchainpy2_midgard.models.saver_details import SaverDetails
from xchainpy2_midgard.models.saver_pool import SaverPool
from xchainpy2_midgard.models.savers_history import SaversHistory
from xchainpy2_midgard.models.savers_history_intervals import SaversHistoryIntervals
from xchainpy2_midgard.models.savers_history_item import SaversHistoryItem
from xchainpy2_midgard.models.savers_history_meta import SaversHistoryMeta
from xchainpy2_midgard.models.stats_data import StatsData
from xchainpy2_midgard.models.streaming_swap_meta import StreamingSwapMeta
from xchainpy2_midgard.models.swap_history import SwapHistory
from xchainpy2_midgard.models.swap_history_intervals import SwapHistoryIntervals
from xchainpy2_midgard.models.swap_history_item import SwapHistoryItem
from xchainpy2_midgard.models.swap_metadata import SwapMetadata
from xchainpy2_midgard.models.thor_name_details import THORNameDetails
from xchainpy2_midgard.models.thor_name_entry import THORNameEntry
from xchainpy2_midgard.models.tvl_history import TVLHistory
from xchainpy2_midgard.models.tvl_history_intervals import TVLHistoryIntervals
from xchainpy2_midgard.models.tvl_history_item import TVLHistoryItem
from xchainpy2_midgard.models.transaction import Transaction
from xchainpy2_midgard.models.withdraw_metadata import WithdrawMetadata
